# Copyright 2024, Seiko Epson Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the “Software”), to deal in
# the Software without restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.


class Constants:
    """アプリケーションで使用される定数をもつ定数クラス"""

    LOGGER_VERSION = "1.0.0"
    PHYSICAL_VELOCITY = "Velocity"
    PHYSICAL_DISPLACEMENT = "Displacement"
    PHYSICAL_ACCELERATION = "Acceleration"
    START_TYPE_AUTO = "auto"
    START_TYPE_MANUAL = "manual"
    START_TYPE_SCHEDULE = "schedule"
    MODE_RAW = "Raw"
    MODE_RMS = "RMS"
    MODE_PP = "P-P"
    SPS_3000 = 3000
    SPS_1000 = 1000
    SPS_500 = 500
    SPS_300 = 300
    SPS_200 = 200
    SPS_100 = 100
    SPS_50 = 50
    BAUD_RATE_230400 = 230_400
    BAUD_RATE_460800 = 460_800
    BAUD_RATE_921600 = 921_600
    LOGGER_ID_PATTERN = r"^[0-9a-zA-Z]{1,63}$"
    INITIAL_WAIT_MIN = 0
    INITIAL_WAIT_MAX = 3600
    MEASURE_TIME_SEC_MIN = 0
    MEASURE_TIME_SEC_MAX = 2**63 - 1
    FILE_ROTATE_MIN_MIN = 1
    FILE_ROTATE_MIN_MAX = 60
    BAUD_RATES = [BAUD_RATE_230400, BAUD_RATE_460800, BAUD_RATE_921600]
    A342_PHYSICALS = [PHYSICAL_VELOCITY, PHYSICAL_DISPLACEMENT]
    A342_MODES = [MODE_RAW, MODE_RMS, MODE_PP]
    A342_RMS_PP_OUTPUT_INTERVAL_MIN = 1
    A342_RMS_PP_OUTPUT_INTERVAL_MAX = 255
    A352_SPSS = [SPS_50, SPS_100, SPS_200, SPS_500, SPS_1000]
    LOG_LEVELS = ["DEBUG", "INFO", "WARN", "ERROR", "CRITICAL"]
    SEC_IN_MINUTE = 60


class ConfigKeys:
    """設定ファイルに記載されるキーの一覧の定数クラス"""

    LOGGER_ID = "LOGGER_ID"
    OUTPUT_PATH = "OUTPUT_PATH"
    INITIAL_WAIT = "INITIAL_WAIT"
    MEASURE_TIME_SEC = "MEASURE_TIME_SEC"
    FILE_ROTATE_MIN = "FILE_ROTATE_MIN"
    BAUD_RATE = "BAUD_RATE"
    A342_PHYSICAL = "A342_PHYSICAL"
    A342_MODE = "A342_MODE"
    A342_RMSPP_OUTPUT_INTERVAL = "A342_RMSPP_OUTPUT_INTERVAL"
    A352_SPS = "A352_SPS"
    LOG_LEVEL = "LOG_LEVEL"


class InfoKeys:
    """計測情報CSVファイルのキーの一覧の定数クラス"""

    OS = "OS"
    LOGGER_VERSION = "LOGGER_VERSION"
    LOGGER_ID = "LOGGER_ID"
    START_TYPE = "START_TYPE"
    TIME_ZONE = "TIME_ZONE"
    DATE = "DATE"
    MEASURE_TIME_SEC = ConfigKeys.MEASURE_TIME_SEC
    INITIAL_WAIT = ConfigKeys.INITIAL_WAIT
    FILE_ROTATE_MIN = ConfigKeys.FILE_ROTATE_MIN
    BAUD_RATE = ConfigKeys.BAUD_RATE
    PORT = "PORT"
    SENSOR = "SENSOR"
    PRODUCT_ID = "PRODUCT_ID"
    SERIAL_NO = "SERIAL_NO"
    FIRM_VER = "FIRM_VER"
    PHYSICAL = "PHYSICAL"
    OUTPUT_TYPE = "OUTPUT_TYPE"
    SPS = "SPS"
    FILTER = "FILTER"
    RMS_PP_INTERVAL = "RMS_PP_INTERVAL"
